summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--cheatsheet/raylib_textures.c3
1 files changed, 1 insertions, 2 deletions
diff --git a/cheatsheet/raylib_textures.c b/cheatsheet/raylib_textures.c
index b199b5d..b89d12b 100644
--- a/cheatsheet/raylib_textures.c
+++ b/cheatsheet/raylib_textures.c
@@ -14,8 +14,7 @@
// Image generation functions
Image GenImageColor(int width, int height, Color color); // Generate image: plain color
- Image GenImageGradientV(int width, int height, Color top, Color bottom); // Generate image: vertical gradient
- Image GenImageGradientH(int width, int height, Color left, Color right); // Generate image: horizontal gradient
+ Image GenImageGradientLinear(int width, int height, int direction, Color start, Color end); // Generate image: linear gradient, direction in degrees [0..360], 0=Vertical gradient
Image GenImageGradientRadial(int width, int height, float density, Color inner, Color outer); // Generate image: radial gradient
Image GenImageChecked(int width, int height, int checksX, int checksY, Color col1, Color col2); // Generate image: checked
Image GenImageWhiteNoise(int width, int height, float factor); // Generate image: white noise